/**
 * 工厂bean
 */
import { Map } from "./HashMap";
import { ValidationProperty } from "./model/validate/ValidationProperty";
import { AnnotationBean } from "./model/AnnotationModel";
/**
 * bean工厂service
 */
export interface BeanFactoryService {
}
/**
 * bean工厂 实现
 */
export declare class BeanFactory implements BeanFactoryService {
    /**
     * 创建Bean
     * @param bean
     * @param annotationBean 初始化bean的相关数据
     */
    static create<T extends object | Function>(bean: T, annotationBean?: AnnotationBean): T;
    /**
     * 创建模型
     * @param bean 需要初始化的bean
     * @param annotationBean 初始化bean的相关数据
     */
    static createModel<T extends object | Function>(bean: T, annotationBean?: AnnotationBean): BeanModel<T>;
    /**
     * 获取名称
     * @param bean
     */
    static getName(bean: object | Function): Function;
    /**
     * 获取Bean
     * @param bean
     */
    static getBean<T extends object | Function>(bean: T): T;
    /**
     * 获取Bean
     * @param bean
     */
    private static getBeanClass;
    /**
     * 获取bean 模型
     * @param bean
     */
    static getBeanModel<T extends object | Function>(bean: T): BeanModel<T>;
    /**
     * 查询Bean
     * @param bean
     */
    static containsBean<T extends Function | object>(bean: T): boolean;
    /**
     * 初始化 验证信息
     * @param bean
     */
    private static initValidate;
}
/**
 * http请求类型
 */
export declare enum HttpMethod {
    GET = "GET",
    POST = "POST",
    DELETE = "DELETE",
    PUT = "PUT",
    OPTIONS = "OPTIONS",
    PATCH = "PATCH"
}
/**
 * 请求的数据类型
 */
export declare enum DataType {
    PARAMS = "PARAMS",
    DEFAULT = "PARAMS",
    JSON = "JSON",
    FORMAT_DATA = "FORMAT_DATA",
    BINARY = "BINARY"
}
/**
 * bean存储操作
 */
export declare enum BeanType {
    /**
     * 请求的方法方法
     */
    METHOD = "METHOD",
    /**
     * 路径
     */
    PATH = "PATH",
    /**
     * 名称
     */
    NAME = "NAME"
}
/**
 * 处理路径问题
 */
export declare class BeanModel<T extends Function> {
    /**
     *  当前类
     */
    private _class;
    /**
     * 具体信息
     */
    private _info;
    /**
     * 验证属性集合
     */
    private validateModel;
    constructor(_class: T);
    set class(value: T);
    get class(): T;
    /**
     * 初始化方法
     * @param target 当前class
     * @param key 方法名称
     * @param path 方法路径信息
     */
    initMethod(target: Object | Function, key: string, path: Path): void;
    /**
     * 初始化class
     * @param target 当前class
     * @param beanData 数据对象
     */
    initClass(target: Object | Function, beanData: BeanData): BeanModel<T>;
    /**
     * 添加验证的属性
     * @param modelFunction 属性函数
     * @param validationProperty 验证的属性信息
     */
    initValidateModel(): BeanModel<T>;
    getValidateModel(): Map<Function, Array<ValidationProperty>>;
    get info(): Map<Function, BeanData>;
    set info(value: Map<Function, BeanData>);
}
/**
 * 路径信息
 */
export declare class Path {
    /**
     * 路径
     */
    path: string | undefined;
    /**
     * 名称
     */
    name: string | undefined;
    /**
     * 请求的类型
     */
    method: HttpMethod | undefined;
    /**
     * api分组
     */
    group: string | undefined;
    /**
     * 数据类型
     */
    dataType: DataType | undefined;
    /**
     * 自定义请求的URL
     */
    url: string | undefined;
    constructor(path?: string, name?: string, method?: HttpMethod, group?: string, dataType?: DataType);
}
/**
 * beanData clas 存储数据
 */
export declare class BeanData extends Path {
    private _methodMap;
    constructor(path?: string, name?: string, method?: HttpMethod, group?: string);
    setUrl(url: string | undefined): BeanData;
    setGroup(group: string): BeanData;
    get methodMap(): Map<string, Path>;
    set methodMap(value: Map<string, Path>);
}
