"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BeanData = exports.Path = exports.BeanModel = exports.BeanType = exports.DataType = exports.HttpMethod = exports.BeanFactory = void 0;
/**
 * 工厂bean
 */
const HashMap_1 = require("./HashMap");
const BaseController_1 = require("./controller/BaseController");
const Annotation_1 = require("./annotation/Annotation");
/**
 * 存储
 */
const store = new HashMap_1.Map();
/**
 * bean工厂 实现
 */
class BeanFactory {
    /**
     * 创建Bean
     * @param bean
     * @param annotationBean 初始化bean的相关数据
     */
    static create(bean, annotationBean = {}) {
        return (this.createModel(bean, annotationBean)).class;
    }
    /**
     * 创建模型
     * @param bean 需要初始化的bean
     * @param annotationBean 初始化bean的相关数据
     */
    // @ts-ignore
    static createModel(bean, annotationBean = {}) {
        let name = this.getName(bean);
        // @ts-ignore
        let beanModel;
        // @ts-ignore
        if (store.containsKey(name) && (beanModel = store.get(name)).class != null && (!annotationBean.replace)) {
            // @ts-ignore
            return store.get(name);
        }
        else {
            // @ts-ignore
            beanModel = new BeanModel(bean instanceof Function ? new bean() : bean);
        }
        // @ts-ignore
        return store.put(name, beanModel);
    }
    /**
     * 获取名称
     * @param bean
     */
    static getName(bean) {
        return bean instanceof Function ? bean : bean.constructor;
    }
    /**
     * 获取Bean
     * @param bean
     */
    static getBean(bean) {
        return this.initValidate(bean);
    }
    /**
     * 获取Bean
     * @param bean
     */
    static getBeanClass(bean) {
        if (store.get(this.getName(bean)) == null) {
            return store.get(this.getName(bean));
        }
        // @ts-ignore
        return store.get(this.getName(bean)).class;
    }
    /**
     * 获取bean 模型
     * @param bean
     */
    // @ts-ignore
    static getBeanModel(bean) {
        // @ts-ignores
        return store.get(this.getName(bean));
    }
    /**
     * 查询Bean
     * @param bean
     */
    static containsBean(bean) {
        // @ts-ignores
        Object.filter(store, s => {
        });
        return store.containsKey(this.getName(bean));
    }
    /**
     * 初始化 验证信息
     * @param bean
     */
    static initValidate(bean) {
        let t = this.getBeanClass(bean);
        // @ts-ignore
        if (t != null && t instanceof BaseController_1.default && !t.validation) {
            let model = BeanFactory.getBeanModel(t).getValidateModel();
            let keys;
            if (model == null) {
                keys = t.getFormValidate();
            }
            else {
                keys = model.getAll();
            }
            for (let key in keys) {
                t.setValidation(key, (0, Annotation_1.getValidationModel)(key));
            }
        }
        return t;
    }
}
exports.BeanFactory = BeanFactory;
/**
 * http请求类型
 */
var HttpMethod;
(function (HttpMethod) {
    HttpMethod["GET"] = "GET";
    HttpMethod["POST"] = "POST";
    HttpMethod["DELETE"] = "DELETE";
    HttpMethod["PUT"] = "PUT";
    HttpMethod["OPTIONS"] = "OPTIONS";
    HttpMethod["PATCH"] = "PATCH";
})(HttpMethod = exports.HttpMethod || (exports.HttpMethod = {}));
/**
 * 请求的数据类型
 */
var DataType;
(function (DataType) {
    DataType["PARAMS"] = "PARAMS";
    DataType["DEFAULT"] = "PARAMS";
    DataType["JSON"] = "JSON";
    DataType["FORMAT_DATA"] = "FORMAT_DATA";
    DataType["BINARY"] = "BINARY";
})(DataType = exports.DataType || (exports.DataType = {}));
/**
 * bean存储操作
 */
var BeanType;
(function (BeanType) {
    /**
     * 请求的方法方法
     */
    BeanType["METHOD"] = "METHOD";
    /**
     * 路径
     */
    BeanType["PATH"] = "PATH";
    /**
     * 名称
     */
    BeanType["NAME"] = "NAME";
})(BeanType = exports.BeanType || (exports.BeanType = {}));
/**
 * 处理路径问题
 */
class BeanModel {
    constructor(_class) {
        /**
         * 具体信息
         */
        this._info = new HashMap_1.Map();
        /**
         * 验证属性集合
         */
        this.validateModel = new HashMap_1.Map();
        this._class = _class;
    }
    set class(value) {
        this._class = value;
    }
    get class() {
        return this._class;
    }
    /**
     * 初始化方法
     * @param target 当前class
     * @param key 方法名称
     * @param path 方法路径信息
     */
    initMethod(target, key, path) {
        this.info.put(BeanFactory.getName(target), new BeanData());
        this.info.get(BeanFactory.getName(target)).methodMap.put(key, path);
    }
    /**
     * 初始化class
     * @param target 当前class
     * @param beanData 数据对象
     */
    initClass(target, beanData) {
        let b;
        if ((b = this.info.get(BeanFactory.getName(target))) == null) {
            b = this.info.put(BeanFactory.getName(target), new BeanData());
        }
        b.path = beanData.path;
        b.name = beanData.name;
        b.group = beanData.group;
        b.method = beanData.method;
        return this;
    }
    /**
     * 添加验证的属性
     * @param modelFunction 属性函数
     * @param validationProperty 验证的属性信息
     */
    initValidateModel() {
        // @ts-ignore
        let modelFunction = this._class.getFormValidate();
        if (modelFunction != null && modelFunction.length > 0) {
            modelFunction.forEach(i => {
                this.validateModel.put(i, []);
            });
        }
        return this;
    }
    getValidateModel() {
        return this.validateModel;
    }
    get info() {
        return this._info;
    }
    set info(value) {
        this._info = value;
    }
}
exports.BeanModel = BeanModel;
/**
 * 路径信息
 */
class Path {
    constructor(path, name, method, group, dataType) {
        /**
         * 数据类型
         */
        this.dataType = DataType.DEFAULT;
        this.path = path;
        this.name = name;
        this.method = method;
        this.group = group;
        this.dataType = dataType;
    }
}
exports.Path = Path;
/**
 * beanData clas 存储数据
 */
class BeanData extends Path {
    constructor(path, name, method, group) {
        super(path, name, method, group);
        this._methodMap = new HashMap_1.Map();
    }
    setUrl(url) {
        this.url = url;
        return this;
    }
    setGroup(group) {
        this.group = group;
        return this;
    }
    get methodMap() {
        return this._methodMap;
    }
    set methodMap(value) {
        this._methodMap = value;
    }
}
exports.BeanData = BeanData;
