import { AxiosPromise } from "csap-axios";
import { Id, Page } from "../param/Page";
import { ResponseManagerModel, Result } from "../model/Result";
import { Request } from "../model/Request";
/**
 * 基本接口定义
 * T 表单类型
 * S 筛选类型
 * R 列表返回类型
 * ID 主键
 */
export default interface BaseDao<T, S extends Page, R, ID> {
    /**
     * 添加
     * @param data
     */
    insert(data: Request<T>): AxiosPromise<Result<boolean>>;
    /**
     *  多条删除
     * @param ids
     */
    deletes(ids: Request<Array<ID>>): AxiosPromise<Result<number>>;
    /**
     *  单条删除
     * @param ids
     */
    delete(ids: Request<Id<ID>>): AxiosPromise<Result<boolean>>;
    /**
     * 查询单条记录
     * @param id
     */
    findById(id: Request<Id<ID>>): AxiosPromise<Result<R>>;
    /**
     * 修改信息
     * @param data
     */
    update(data: Request<T>): AxiosPromise<Result<boolean>>;
    /**
     * 分页查询-返回总条数
     * @param data
     */
    queryManagerListPage(data: Request<S>): AxiosPromise<Result<ResponseManagerModel<R>>>;
    /**
     * 分页查询
     * @param data
     */
    queryListPage(data: Request<S>): AxiosPromise<Result<Array<R>>>;
    /**
     * 不分页查询
     * @param data
     */
    query(data: Request<S>): AxiosPromise<Result<Array<R>>>;
}
